@@ -1,6 +1,6 @@
-#' Colour palette
+#' Colour Palette
 #'
-#' Provides qualitative, diverging and sequential colour palettes.
+#' Provides qualitative, diverging and sequential colour schemes.
 #' @param palette A \code{\link{character}} string giving the name of
 #'  the palette to be used (see below).
 #' @param reverse A \code{\link{logical}} scalar specifying if the resulting
@@ -9,19 +9,55 @@
 #'  colours should be kept in the resulting vector.
 #' @param ... Further arguments passed to \code{\link[grDevices]{colorRampPalette}}.
 #' @section Paul Tol's Colour Schemes:
-#'  The following palettes are available (maximum supported colours in brackets):
+#'  The following palettes are available. The maximum number of supported
+#'  colours is in brackets, this value is only relevant for the qualitative
+#'  colour schemes (divergent and sequential schemes are linearly interpolated).
 #'  \describe{
-#'   \item{Qualitative data}{bright (7), contrast (3),vibrant (7), muted (9),
-#'   light (9).}
+#'   \item{Qualitative data}{bright (7), contrast (3), vibrant (7), muted (9),
+#'   pale (6), dark (6), light (9).}
 #'   \item{Diverging data}{sunset (11), BuRd (9), PRGn (9).}
-#'   \item{Sequential data}{YlOrBr (9), discrete rainbow (23),
+#'   \item{Sequential data}{YlOrBr (9), iridescent (23), discrete rainbow (23),
 #'   smooth rainbow (34).}
 #'  }
-#' @section Scientific Colour Schemes:
-#'  The following palettes are available:
+#' @section Qualitative colour schemes:
+#'  According to Paul Tol's technical note, the \code{bright}, \code{contrast},
+#'  \code{vibrant} and \code{muted} colour schemes are colour-blind safe.
+#'
+#'  The \code{light} colour scheme is reasonably distinct for both normal or
+#'  colour-blind vision and is intended to fill labelled cells.
+#'
+#'  The \code{pale} and \code{dark} schemes are not very distinct in either
+#'  normal or colour-blind vision and should be used as a text background or
+#'  to highlight a cell in a table.
+#'
+#'  Refer to the original document for details about the recommended uses (see
+#'  references).
+#' @section Rainbow colour scheme:
+#'  As a general rule, ordered data should not be represented using a rainbow
+#'  scheme. There are three main arguments against such use (Tol 2018):
+#'  \itemize{
+#'   \item{The spectral order of visible light carries no inherent magnitude
+#'   message.}
+#'   \item{Some bands of almost constant hue with sharp transitions between
+#'   them, can be perceived as jumps in the data.}
+#'   \item{Colour-blind people have difficulty distinguishing some colours of
+#'   the rainbow.}
+#'  }
+#'  If such use cannot be avoided, Paul Tol's technical note provides two colour
+#'  schemes that are reasonably clear in colour-blind vision. To remain
+#'  colour-blind safe, these two schemes must comply with the following
+#'  conditions:
 #'  \describe{
-#'   \item{stratigraphy}{International Chronostratigraphic Chart}
-#'   \item{soil}{FAO Reference Soil Groups}
+#'   \item{discrete rainbow}{This scheme must not be interpolated.}
+#'   \item{smooth rainbow}{This scheme does not have to be used over the full
+#'   range.}
+#'  }
+#' @section Scientific Colour Schemes:
+#'  The following (qualitative) colour schemes are available:
+#'  \describe{
+#'   \item{stratigraphy}{International Chronostratigraphic Chart (175 colours).}
+#'   \item{land}{AVHRR Global Land Cover Classification (14 colours).}
+#'   \item{soil}{FAO Reference Soil Groups (24 colours).}
 #'  }
 #' @return A palette function that when called with a single integer argument
 #'  (the number of levels) returns a vector of colours.
@@ -49,9 +85,10 @@ colour <- function(palette, reverse = FALSE, names = TRUE, ...) {
   missing <- col_scheme[["missing"]]
   scheme <- col_scheme[["scheme"]]
 
-  k <- if (palette == "rainbow") 23 else length(colours)
+  k <- if (palette == "discrete rainbow") 23 else length(colours)
 
   if (reverse) colours <- rev(colours) # Reverse colour order
+
   if (interpolate) {
     # For colour schemes that can be linearly interpolated
     fun <- grDevices::colorRampPalette(colours, ...)
@@ -63,14 +100,14 @@ colour <- function(palette, reverse = FALSE, names = TRUE, ...) {
         stop("You ask for too many colours: ", palette,
              " colour scheme supports up to ", k, " values.", call. = FALSE)
       # Arrange colour schemes
-      col <- if (palette == "rainbow") colours[scheme[[n]]] else colours
+      col <- if (palette == "discrete rainbow") colours[scheme[[n]]] else colours
       col <- if (names) col else unname(col)
       return(col)
     }
   }
   attr(fun, "type") <- type
   attr(fun, "interpolate") <- as.logical(interpolate)
-  attr(fun, "missing") <- as.logical(missing)
+  attr(fun, "missing") <- missing
   attr(fun, "max") <- as.integer(k)
   return(fun)
 }
