@@ -4,19 +4,20 @@ NULL
 
 #' Colour scale constructor
 #'
-#' Builds discrete or continuous scale for 'ggplot2' according to the color
+#' Builds discrete or continuous scale for 'ggplot2' according to the colour
 #'  scheme used.
 #' @param aesthetics The names of the aesthetics that this scale works with.
-#' @param palette A \code{\link{character}} string giving the name of
+#' @param scale_name A \code{\link{character}} string giving the name of
 #'  the palette to be used (see \code{\link{colour}}).
 #' @param reverse A \code{\link{logical}} scalar specifying if the resulting
 #'  vector of colours should be reversed.
+#' @param midpoint A \code{\link{numeric}} value specifying the midpoint (in
+#'  data value) of the diverging scale (defaults to \eqn{0}).
 #' @param ... Further arguments passed to \code{\link[ggplot2]{discrete_scale}}
 #'  or \code{\link[ggplot2]{continuous_scale}}, used respectively for
 #'  qualitative data and diverging/sequential data.
 #' @author N. Frerebeau
 #' @keywords internal
-#' @noRd
 scale <- function(aesthetics, scale_name, reverse = FALSE, midpoint = 0, ...) {
   # Get colour palette and scheme information
   palette <- colour(scale_name, reverse, names = FALSE)
@@ -34,7 +35,7 @@ scale <- function(aesthetics, scale_name, reverse = FALSE, midpoint = 0, ...) {
     scale_arguments[["guide"]] <- if(interpolate) "colourbar" else "legend"
   }
 
-  if (type == "qualitative") {
+  if (!interpolate) {
     do.call(ggplot2::discrete_scale,
             c(aesthetics, scale_name, palette, scale_arguments))
   } else {
