@@ -1,27 +1,29 @@
 library(scales)
 
-# Paul Tol's colour schemes
-## Qualitative data
+## Paul Tol's colour schemes
+### Qualitative data
 show_col(colour("bright")(7))
 show_col(colour("contrast")(3))
 show_col(colour("vibrant")(7))
+show_col(colour("pale")(6))
+show_col(colour("dark")(6))
 show_col(colour("muted")(9))
 show_col(colour("light")(9))
-## Diverging data
+### Diverging data
 show_col(colour("sunset")(11))
 show_col(colour("BuRd")(9))
 show_col(colour("PRGn")(9))
-## Sequential data
+### Sequential data
 show_col(colour("YlOrBr")(9))
 show_col(colour("iridescent")(23))
-show_col(colour("rainbow")(14))
-show_col(colour("rainbow")(23))
+show_col(colour("discrete rainbow")(14))
+show_col(colour("discrete rainbow")(23))
 show_col(colour("smooth rainbow")(34))
 
-# Scientific colour schemes
-## Geologic Timescale
+## Scientific colour schemes
+### Geologic timescale
 show_col(colour("stratigraphy")(175))
-## AVHRR global land cover classification
+### AVHRR global land cover classification
 show_col(colour("land")(14))
-## FAO soil reference groups
+### FAO soil reference groups
 show_col(colour("soil")(24))
